# Configure SharePoint
# 8 June 2010 Dan Holme (danh@intelliem.com)
# 
# This script configures SharePoint Server 2010 
# on the first server in a farm
# 
# The script is to be run after installing SharePoint (setup.exe)
# which itself can be automated by using config.xml.
#
# The script uses the same settings--and to the same effect--as the wizard-driven
# SharePoint 2010 Products Configuration Wizard.
# But gives you the advantage of an automated configuration method,
# and of defining the Admin database name, which cannot be specified in the UI.
##
# The script is a derivative of the TechNet script
# http://technet.microsoft.com/en-us/library/ee805951.aspx
# However this script fixes a bug and tidies up some code


# ---------------------------------------------------------------------------------
# CUSTOMIZATION BLOCK
# Settings to change

#Farm
$FarmAccount       = "CONTOSO\SP_Farm"
$ConfigDBName      = "SharePoint_Config"
$AdminDBName       = "SharePoint_AdminContent"
$DBServer          = "SP2010-WFE1"

# Central Administration
$CAPort            = "9999"
$WinAuthProvider   = "NTLM"

# Security-sensitive values are prompted, rather than hard-coded

Write-Host "Geben Sie die Anmeldeinformationen fuer das SharePoint-Farmkonto ein"

$FarmCredential    = Get-Credential $FarmAccount

$Passphrase        = Read-Host -Prompt "Geben Sie das Farmkennwort ein" -AsSecureString

# To hard code:    = ConvertTo-SecureString "<password>" AsPlaintext Force
# but not recommended to hard code a password in a production environment

#
# ---------------------------------------------------------------------------------

if ([String]::IsNullOrEmpty($FarmCredential))
{
    Write-Error "Sie muessen den Benutzernamen und das kennwort eines Farmadministrators eingeben"
    return
}
if ($Passphrase.Length -eq 0)
{
    Write-Error "Sie haben kein Farmkennwort eingegeben."
    return
}

# ---------------------------------------------------------------------------------
# CONFIGURE SHAREPOINT

$err = $null

Write-Host
Write-Host "KONFIGURIERE SHAREPOINT SERVER 2010"
Write-Host "Bitte warten..."
    
Add-PSSnapin Microsoft.SharePoint.PowerShell -erroraction SilentlyContinue

Write-Host "[1/9] Erstelle die SharePoint-Konfigurationsdatenbank..." 
New-SPConfigurationDatabase -DatabaseName $ConfigDBName  -DatabaseServer $DBServer -AdministrationContentDatabaseName $AdminDBName -FarmCredentials $FarmCredential -Passphrase $Passphrase -ErrorVariable err

Write-Host "[2/9] Ueberpruefe Farmerstellung..." 
$spfarm = get-spfarm

if ($spfarm -ne $null) {
    Write-Host "[3/9] Sichere SharePoint-Ressourcen..." 
    Initialize-SPResourceSecurity -ErrorVariable err

    if ([String]::IsNullOrEmpty($err) -eq $true) {
        Write-Host "[4/9] Installiere Dienste..." 
        Install-SPService -ErrorVariable err

        if ([String]::IsNullOrEmpty($err) -eq $true) {
            Write-Host "[5/9] Installiere Features..." 
            Install-SPFeature -AllExistingFeatures -ErrorVariable err

            if ([String]::IsNullOrEmpty($err) -eq $true) {
                Write-Host "[6/9] Stelle Zentraladministration bereit..." 
                New-SPCentralAdministration -Port $CAPort -WindowsAuthProvider $WinAuthProvider -ErrorVariable err

                if ([String]::IsNullOrEmpty($err) -eq $true) {
                    Write-Host "[7/9] Installiere Hilfe..." 
                    Install-SPHelpCollection -All -ErrorVariable err

                    if ([String]::IsNullOrEmpty($err) -eq $true) {
                        Write-Host "[8/9] Installiere Anwendungsinhalt..." 
                        Install-SPApplicationContent -ErrorVariable err

                        if ([String]::IsNullOrEmpty($err) -eq $true) {
                            Write-Host "[9/9] Grundkonfiguration abgeschlossen." 

                        } else { Write-Error "FEHLER: $err" }
                    } else { Write-Error "FEHLER: $err" }
                } else { Write-Error "FEHLER: $err" }
            } else { Write-Error "FEHLER: $err" }
        } else { Write-Error "FEHLER: $err" }
    } else { Write-Error "FEHLER: $err" }
} else { Write-Error "FEHLER: $err" }
 
$exitprompt = Read-Host -Prompt "Druecken Sie die Eingabetaste, um den Vorgang abzuschliessen"
